==> org.eclipse.passage.loc.workbench.emfforms.source_0.6.0.v20200505-1936.jar: org/eclipse/passage/loc/workbench/emfforms/renderers/ConditionTypeRenderer.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0/.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.loc.workbench.emfforms.renderers;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.eclipse.emf.ecp.view.spi.context.ViewModelContext;
import org.eclipse.emf.ecp.view.spi.model.VControl;
import org.eclipse.emf.ecp.view.template.model.VTViewTemplateProvider;
import org.eclipse.emfforms.spi.common.report.ReportService;
import org.eclipse.emfforms.spi.core.services.databinding.EMFFormsDatabinding;
import org.eclipse.emfforms.spi.core.services.label.EMFFormsLabelProvider;
import org.eclipse.passage.lic.api.access.PermissionEmitterRegistry;

public class ConditionTypeRenderer extends ComboControlRenderer {

	private final PermissionEmitterRegistry conditionInpector;

	@Inject
	public ConditionTypeRenderer(VControl vElement, ViewModelContext viewContext, ReportService reportService,
			EMFFormsDatabinding emfFormsDatabinding, EMFFormsLabelProvider emfFormsLabelProvider,
			VTViewTemplateProvider vtViewTemplateProvider) {
		super(vElement, viewContext, reportService, emfFormsDatabinding, emfFormsLabelProvider, vtViewTemplateProvider);
		this.conditionInpector = viewContext.getService(PermissionEmitterRegistry.class);
	}

	@Override
	protected String getUnsetText() {
		return conditionInpector.getDefaultConditionType();
	}

	@Override
	protected List<String> getDefinedValues() {
		List<String> values = new ArrayList<>();
		conditionInpector.getSupportedConditionTypes().forEach(values::add);
		return values;
	}

}

==> org.eclipse.passage.loc.workbench.emfforms.source_1.0.0.v20200902-1901.jar: org/eclipse/passage/loc/workbench/emfforms/renderers/ConditionTypeRenderer.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0/.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.loc.workbench.emfforms.renderers;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.eclipse.emf.ecp.view.spi.context.ViewModelContext;
import org.eclipse.emf.ecp.view.spi.model.VControl;
import org.eclipse.emf.ecp.view.template.model.VTViewTemplateProvider;
import org.eclipse.emfforms.spi.common.report.ReportService;
import org.eclipse.emfforms.spi.core.services.databinding.EMFFormsDatabinding;
import org.eclipse.emfforms.spi.core.services.label.EMFFormsLabelProvider;
import org.eclipse.passage.lic.internal.equinox.EnvironmentNames;

@SuppressWarnings("restriction")
public class ConditionTypeRenderer extends ComboControlRenderer {

	private final List<String> environments;

	@Inject
	public ConditionTypeRenderer(VControl vElement, ViewModelContext viewContext, ReportService reportService,
			EMFFormsDatabinding emfFormsDatabinding, EMFFormsLabelProvider emfFormsLabelProvider,
			VTViewTemplateProvider vtViewTemplateProvider) {
		super(vElement, viewContext, reportService, emfFormsDatabinding, emfFormsLabelProvider, vtViewTemplateProvider);
		// FIXME: work for caching supplier
		environments = new EnvironmentNames().get();
	}

	@Override
	protected String getUnsetText() {
		return environments.size() > 0 ? environments.get(0) : ""; //$NON-NLS-1$
	}

	@Override
	protected List<String> getDefinedValues() {
		return new ArrayList<>(environments);
	}

}
